#
# spec file for package fluidsynth
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# fix build for older distros and architectures where _fillupdir is
# not yet defined by using the old path as recommended by
# https://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25_fillupdir
%if ! %{defined _fillupdir}
 %define _fillupdir /var/adm/fillup-templates
%endif

Name:           fluidsynth
Version:        1.1.11
Release:        6.11
Summary:        A Real-Time Software Synthesizer That Uses Soundfont(tm)
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Sound/Midi
Url:            http://www.fluidsynth.org/
Source:         https://github.com/FluidSynth/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1000:     baselibs.conf
BuildRequires:  cmake >= 3.0.2
BuildRequires:  ladspa-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(sndfile)
%{?systemd_requires}
PreReq:         %fillup_prereq

%description
FluidSynth (formerly IIWU Synth) is a real-time software synthesizer
based on the SoundFont(tm) 2 specifications. It can read MIDI events
from the MIDI input device and render them to the audio device. It
can also play MIDI files.

%package devel
Summary:        Development package for the fluidsynth library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libfluidsynth1 = %{version}
Provides:       libfluidsynth-devel = %{version}

%description devel
This package contains the files needed to compile programs that use the
fluidsynth library.

%package -n libfluidsynth1
Summary:        Library for Fluidsynth
Group:          System/Libraries

%description -n libfluidsynth1
This package contains the shared library for Fluidsynth.

%prep
%setup -q

%build
%cmake \
    -DFLUID_DAEMON_ENV_FILE=%{_fillupdir}/sysconfig.%{name} \
    -Denable-ladspa=1 \
    -Denable-lash=0
make %{?_smp_mflags}

%install
%cmake_install

# manually install systemd service files
install -Dm 644 build/fluidsynth.conf %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -Dm 644 build/fluidsynth.service %{buildroot}%{_unitdir}/%{name}.service
install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%post -n libfluidsynth1 -p /sbin/ldconfig
%postun -n libfluidsynth1 -p /sbin/ldconfig

%pre
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc AUTHORS ChangeLog NEWS README.md THANKS TODO
%{_mandir}/man?/*
%{_bindir}/*
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n libfluidsynth1
%{_libdir}/lib*.so.*

%changelog
* Sun May  6 2018 tom.mbrt@googlemail.com
- Update to 1.1.11:
  * fix pkgconfig file for absolute paths
  * add a cmake option for OSS support
  * fix broken enable-midishare cmake option
  * fix double free in fluid_midi_router
  * prevent malicious soundfonts from causing buffer overflows
  * avoid SF3 files to be loaded incorrectly
  * fix an endless loop in fast file renderer
- remove 0001-Fix-pkgconfig-file-for-absolute-paths-347.patch
* Tue Mar  6 2018 tom.mbrt@googlemail.com
- Add 0001-Fix-pkgconfig-file-for-absolute-paths-347.patch
  to fix pkgconfig file generation when absolute lib and include
  paths are used (boo#1084081)
* Fri Mar  2 2018 tom.mbrt@googlemail.com
- Avoid using indirection macros
- Do not hard-code /usr/sbin
* Sun Feb 25 2018 tom.mbrt@googlemail.com
- Update to 1.1.10:
  * avoid a buffer overrun when loading malformed soundfonts
  * fix synth.default-soundfont returning incomplete path
  * improve reliability of fluid_is_soundfont()
  * include windows version info in libfluidsynth.dll
  * enable jack midi driver to support more than 16 midi channels
  * minor cmake adjustments for MSVC builds to enable building fluidsynth as vcpkg package
  * fix build issues against statically built fluidsynth library on all OSs
  * enable fluidsynth to be set up as systemd user service
  * cmake: prevent double usage of LIB_SUFFIX and LIB_INSTALL_DIR
- Install systemd service files
* Thu Feb 15 2018 tchvatal@suse.com
- Switch to cmake macros
- Use %%license to install license
- Disable optional lash support as we try to remove lash
- Format with spec-cleaner
* Thu Jan  4 2018 tom.mbrt@googlemail.com
- Update to version 1.1.9:
  * fix building the portaudio driver on Windows
  * fix build if no MIDI drivers are available
  * fix return value of fluid_file_set_encoding_quality()
  * fix use-after-free in fluid_timer
  * fix memory leak in pulseaudio driver
  * fix memory leak in rvoice_mixer
  * fix dumptuning shell command displaying uninitialized values
  * fix a resource leak in source shell command
  * harmonize fluidsynth's output library naming with autotools on Windows
  * dont set LIB_SUFFIX when building with MinGW
  * avoid a possible deadlock when initializing fluidsynths DLL on windows
  * avoid a buffer overrun when mixing effects channels in fluid_synth_nwrite_float()
  * correctly clean up fluid_server on Windows
  * implement handling of FLUID_SEQ_ALLSOUNDSOFF events in fluid_seq_fluidsynth_callback()
  * support for registering audio drivers based on actual needs
* Fri Oct 13 2017 tom.mbrt@googlemail.com
- Update to version 1.1.8:
  * fix build against glib < 2.30
  * fix dsound audio driver on windows
  * fix a bug around `synth.audio-groups` setting, which caused improper multi-channel rendering
  * cmake 3.0.2 is now required
  * compilation with clang is now possible
  * build fixes on OS/2
- Use pkgconfig for resolving build requirements
- Minor description update
* Wed Sep  6 2017 tom.mbrt@googlemail.com
- Update to version 1.1.7:
  * consistently relicense libfluidsynth under LGPL-2.1+
  * fluid_synth_set_channel_type() was not exported properly
  * fix calculations for modulators
  * fix SysEx parsing issues
  * fix mangling with illegal sample loops, causing audible glitches
  * fix inverse logic of audio.jack.multi option
  * fix channel fine tune RPN to use correct range
  * fix timing problems when changing the sequencers scale from a callback event
  * workaround incorrectly rendered audio when requesting more than 64 frames from fluid_synth_write_*()
  * adjust ALSA MIDI port type
  * avoid voice_count becoming negative
  * avoid notes with a fixed key generator playing forever
  * avoid TCP/IP connections from closing in an undefined manner
  * a lot of memory leaks, NULL dereferences and SegFaults
  * add support of vorbis-compressed sf3 sound fonts
  * add sostenuto pedal to the synth
  * add vbr quality when encoding with libsndfile
  * re-implement routing reverb and chorus to distinct buffers in fluid_synth_nwrite_float()
  * add IPv6 support to socket API
- remove the following patches as they got fixed upstream:
  * fluidsynth-fix-build-lash.diff
  * jackmulti.diff
  * reverb_mixer.diff
* Sun Nov 22 2015 idonmez@suse.com
- Add baselibs.conf as a source file
* Sun Nov 22 2015 tom.mbrt@googlemail.com
- Added jackmulti.diff to fix inverse logic of audio.jack.multi option
- Added reverb_mixer.diff to workaround reverb issue,
  see: http://sourceforge.net/p/fluidsynth/tickets/137/
* Mon Sep 24 2012 schwab@linux-m68k.org
- Use %%{optflags}
* Fri Sep 21 2012 zaitor@opensuse.org
- Update to version 1.1.6:
  + Handle MIDI End of track events.
  + Prevent broken rendering after an voice overflow.
  + Enable long arguments where available.
  + Windows: Install fluidsynth.pc (pkg-config spec).
  + Mac OS X Lion: Fix build failure.
  + Linux: Prevent libdbus crash.
* Mon Jun  4 2012 toddrme2178@gmail.com
- Added 32-bit compatibility library (needed by
  gstreamer-0_10-plugins-buzztard-32bit )
* Tue Jan 10 2012 reddwarf@opensuse.org
- Updated to 1.1.5
  + Autotools build resulted in the wrong version number for
    libfluidsynth.so
  + One symbol was dropped from libfluidsynth.so - this symbol was
    not part of the public API though
  + JACK: Using jack_free instead of free when needed
  + Update Free Software Foundation address
- Run spec-cleaner
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Aug  8 2011 tiwai@suse.de
- Updated to version 1.1.4:
  Improvements to the API for playing MIDI files, several bug fixes
  in the engine itself; for details, see:
    http://sourceforge.net/apps/trac/fluidsynth/wiki/ChangeLog1_1_4
- Use cmake for build
- Re-add a symbol dropped from 1.1.3
- Clean up spec file
* Fri Dec 31 2010 lnussel@suse.de
- provide libfluidsynth-devel for compatibility with packman
* Mon Oct 11 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.3:
  + Compilation with LADSPA enabled was broken in 1.1.2
  + Multichannel output broken when double precision was used
  + Doxygen settings
  + Fix build problem with scummvm
  + Optimize by not starting unused threads with multicore rendering
  + Race condition in alsa_seq / alsa_raw drivers caused them not to quit
* Thu Sep  2 2010 oliver.bengs@opensuse.org
- Updated to version 1.1.2:
  see details in
  http://sourceforge.net/apps/trac/fluidsynth/wiki/ChangeLog1_1_2
- disabled LADSPA, because it is broken in this release
- enabled dbus and libsndfile
* Fri Apr  2 2010 davejplater@gmail.com
- Updated to version 1.1.1
- FluidSynth 1.1.1 - "Clarity", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_1
  This is a rather major bug fix release to version 1.1.0.
  FluidSynth 1.1.0 - "A More Solid Fluid", see Changes page for details.
  http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_1_0
  This is the result of a 6 month development cycle and is the most
  significant release since 1.0.0!
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.0.9:
  see details in
    http://fluidsynth.resonance.org/trac/wiki/ChangeLog1_0_9
- add support of pulseaudio and LASH
* Mon Apr 14 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Tue Nov 20 2007 tiwai@suse.de
- updated to version 1.0.8:
  * Improved synthesis interpolation
  * Dithering on 16 bit converted output
  * Updated fluidmax plugin with polyphony parameter.
  * Improved ALSA audio and sequencer drivers.
  * Fixed some Floating Point Exceptions which were causing
    excessive CPU usage
  * Some fixes to Chorus and Reverb parameters
  * Looping/tuning problem when loop end close to end of sample
  * FluidSynth crashes with QSynth and audio meters turned on
  * ALSA sequencer driver no longer prints out false errors
  * Many memory leaks plugged
  * Warning message printed if a non option is not a valid
    SoundFont or MIDI file
* Tue Apr 17 2007 tiwai@suse.de
- follow library packaging policy
  * split shared library to libfluidsynth1 sub package
  * remove static library
- fix buildrequires ladspa-devel
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.7a.
  * cleanup of LADCCA support
  * fix warnings with JACK backend
  * fix sequencer buffer overrun bug
  * new filter routine
  * crash bugfix
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 tiwai@suse.de
- fix the crash with 64bit architectures (#137998)
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Tue Jun 14 2005 tiwai@suse.de
- updated to version 1.0.6.
- split fluidsynth-dssi to an individual package (built from
  own tarball).
* Fri Apr  8 2005 tiwai@suse.de
- fix for gcc-4.0.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.0.5.
* Tue Aug 17 2004 tiwai@suse.de
- fixed the build of fluidsynth-dssi plugin.
* Tue Aug 17 2004 tiwai@suse.de
- Added the DSSI plugin support.
  A new subpackage fluidsynth-dssi is created.
* Mon Apr 26 2004 ro@suse.de
- add -fno-strict-aliasing
* Tue Jan 13 2004 tiwai@suse.de
- added non-root build.
- added %%run_ldconfig.
- fixed %%defattr.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 1.0.3.
* Thu Aug 28 2003 tiwai@suse.de
- fixed bugs; retrieved from 1.0.3.
* Thu Jul  3 2003 tiwai@suse.de
- updated to version 1.0.2.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 1.0.1.
* Thu Mar 27 2003 tiwai@suse.de
- initial version 1.0.0.  iiwusynth is obsoleted.
